==> pywebkit-0.1.3.tar.gz: pywebkit-0.1.3/README.md <==
# PyWebKit - The simplest Python Web Kit out there!

With PyWebKit, you can modernize websites with python with just one line of code. PyWebKit is super easy to use and handles everything for you. Just specify what website you want to call and what media you want to receive back, and the rest is done for you.

# Overview
The PyWebKit Python caller was written with fast use in mind. It provides the following key features

  - call methods - Every function has its own property.
  - The most common call activities (CSS generator) are already implemented
  - Receive special file types like .css


## Usage

In the following paragraphs, I am going to describe how you can get and use PyWebKit for your own projects.

###  Getting it

To download PyWebKit, either fork this github repo or simply use Pypi via pip.
```sh
$ pip install pywebkit
```

### Using it

PyWebKit was programmed with ease-of-use in mind. First, import "css class maker" and Page from PyWebKit

```Python
from pywebkit import css_class_maker
```

And you are ready to go! At this point, I want to clearly distinct what is css class maker. It is just nothing but to create a css file with classes.

Yep, thats all. Just specify that you need to implement import functions


#### Dowload file type (*css*)

## Try out the below code

```Python

from pywebkit import css_class_maker

css_class_generator()

```

License
----

MIT License
Copyright (c) 2018 MOHAMED YASEEN SHERIFF S

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


My Portfolio
https://yaseen.netlify.com

==> pywebkit-0.1.5.tar.gz: pywebkit-0.1.5/README.md <==
# PyWebKit - The simplest Python Web Kit out there!

With PyWebKit, you can modernize websites with python with just one line of code. PyWebKit is super easy to use and handles everything for you. Just specify what website you want to call and what media you want to receive back, and the rest is done for you.

# Overview
The PyWebKit Python caller was written with fast use in mind. It provides the following key features

  - call methods - Every function has its own property.
  - The most common call activities (CSS generator) are already implemented
  - Receive special file types like .css
  - newlines integrated, now you can print newlines just by calling "newline1()" and upto 6 lines


## Usage

In the following paragraphs, I am going to describe how you can get and use PyWebKit for your own projects.

###  Getting it

To download PyWebKit, either fork this github repo or simply use Pypi via pip.
```sh
$ pip install pywebkit
```

### Using it

PyWebKit was programmed with ease-of-use in mind. First, import "css class maker" from PyWebKit

```Python
from pywebkit import css_class_maker

		# OR

from pywebkit import *
```

And you are ready to go! At this point, I want to clearly distinct what is css class maker. It is just nothing but to create a css file with classes.

Yep, thats all. Just specify that you need to implement import functions


#### Dowload file type (*css*)

## Try out the below code

```Python

from pywebkit import css_class_maker

css_class_generator()

		# or

from pywebkit import *

css_class_generator()

newline2()


```

License
----

MIT License

Copyright (c) 2018 MOHAMED YASEEN SHERIFF S

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


My Portfolio:
https://yaseen.netlify.com
